pub struct Dispatcher<T: Trigger> { }
Represents a dispatcher for collecting triggers.
Type Parameters
T - The trigger type implementing the Trigger trait.
Creates a new Dispatcher instance.
Returns
A new Dispatcher ready to create notifiers and collect triggers.
Errors
Returns an error if the dispatcher cannot be initialized.
Returns a Notifier associated with the dispatcher.
Returns
A Notifier linked to this dispatcher’s notification system.
Errors
Returns an error if the notifier cannot be created.
Collects triggers from the notification system.
Returns
A HashSet of collected triggers.
Errors
Returns an error if the collection fails.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.